summaryrefslogtreecommitdiff
path: root/Master
diff options
context:
space:
mode:
authorNorbert Preining <preining@logic.at>2018-09-06 15:01:34 +0000
committerNorbert Preining <preining@logic.at>2018-09-06 15:01:34 +0000
commit3cfca261803ef30166b28372b7be7d433a34f3d7 (patch)
treee68dfd300a0c7e2fd55cfa9fc3bfbb431b3a4b6d /Master
parentd05ed17e8332892a63a7d1b533e8a2cc11a93739 (diff)
update tlmgr pinning doc to refer to correct tlcontrib
git-svn-id: svn://tug.org/texlive/trunk@48598 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Master')
-rwxr-xr-xMaster/texmf-dist/scripts/texlive/tlmgr.pl30
1 files changed, 14 insertions, 16 deletions
diff --git a/Master/texmf-dist/scripts/texlive/tlmgr.pl b/Master/texmf-dist/scripts/texlive/tlmgr.pl
index 9f31e43cbc0..00960f79f31 100755
--- a/Master/texmf-dist/scripts/texlive/tlmgr.pl
+++ b/Master/texmf-dist/scripts/texlive/tlmgr.pl
@@ -9228,46 +9228,44 @@ only one enabled (as is the case by default):
/var/www/norbert/tlnet
Ok. Let's add the C<tlcontrib> repository (this is a real
-repository, hosted at L<http://tlcontrib.metatex.org>, maintained by
-Taco Hoekwater et al.), with the tag C<tlcontrib>:
+repository hosted at L<http://contrib.texlive.info>) with the tag C<tlcontrib>:
- $ tlmgr repository add http://tlcontrib.metatex.org/2012 tlcontrib
+ $ tlmgr repository add http://contrib.texlive.info/current tlcontrib
Check the repository list again:
$ tlmgr repository list
List of repositories (with tags if set):
- http://tlcontrib.metatex.org/2012 (tlcontrib)
+ http://contrib.texlive.info/current (tlcontrib)
/var/www/norbert/tlnet (main)
-Now we specify a pinning entry to get the package C<context> from
+Now we specify a pinning entry to get the package C<classico> from
C<tlcontrib>:
- $ tlmgr pinning add tlcontrib context
+ $ tlmgr pinning add tlcontrib classico
-Check that we can find C<context>:
+Check that we can find C<classico>:
- $ tlmgr show context
- tlmgr: package repositories:
+ $ tlmgr show classico
+ package: classico
...
- package: context
- repository: tlcontrib/26867
+ shortdesc: URW Classico fonts
...
-- install C<context>:
+- install C<classico>:
- $ tlmgr install context
+ $ tlmgr install classico
tlmgr: package repositories:
...
- [1/1, ??:??/??:??] install: context @tlcontrib [
+ [1/1, ??:??/??:??] install: classico @tlcontrib [737k]
-In the output here you can see that the C<context> package has been
+In the output here you can see that the C<classico> package has been
installed from the C<tlcontrib> repository (C<@tlcontrib>).
Finally, C<tlmgr pinning> also supports removing certain or all packages
from a given repository:
- $ tlmgr pinning remove tlcontrib context # remove just context
+ $ tlmgr pinning remove tlcontrib classico # remove just classico
$ tlmgr pinning remove tlcontrib --all # take nothing from tlcontrib
A summary of the C<tlmgr pinning> actions is given above.